===============================
Tool Tree Widget (``tooltree``)
===============================

.. automodule:: orangecanvas.gui.tooltree

.. autoclass:: orangecanvas.gui.tooltree.ToolTree
   :members:
   :member-order: bysource
   :show-inheritance:

   .. autoattribute:: triggered(QAction)

      Signal emitted when an action in the widget is triggered.

   .. autoattribute:: hovered(QAction)

      Signal emitted when an action in the widget is hovered.
